@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2011-2021 Canonical
- * Copyright (C) 2021-2023 Colin Ian King
+ * Copyright (C) 2021-2024 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -344,7 +344,7 @@ static int get_pid_max_digits(void)
 
 	buf[n] = '\0';
 	digits = 0;
-	while (buf[digits] >= '0' && buf[digits] <= '9')
+	while ((digits < n) && (buf[digits] >= '0') && (buf[digits] <= '9'))
 		digits++;
 	if (digits < min_digits)
 		digits = min_digits;
